@@ -132,11 +132,7 @@ $smarty->assign('prompt_type', lang('type'));
 
 $smarty->assign('prompt_template', lang('code'));
 $smarty->assign('template', $this->CreateSyntaxArea ($id, $contents, 'templatecontent'));
-/*
-$smarty->assign('availablevariables', $this->Lang('availablevariables'));
-$smarty->assign('availablevariableslist', $this->Lang('availablevariableslist'));
-$smarty->assign('availablevariableslink', $gCms->variables['admintheme']->DisplayImage('icons/system/info.gif', $this->Lang('availablevariables'),'','','systemicon'));
-*/
+
 $smarty->assign('submit', $this->CreateInputSubmit ($id, 'submitbutton', lang('submit')));
 $smarty->assign('apply', $params['mode'] == 'add' ? '' : $this->CreateInputSubmit($id, 'applybutton', lang('apply')));
 $smarty->assign('cancel', $this->CreateInputSubmit ($id, 'cancel', lang('cancel')));
