@@ -9,7 +9,7 @@
 #-------------------------------------------------------------------------
 
 
-$gbooks = Gbook_utils::GetGbooks('', false);
+//$gbooks = Gbook_utils::GetGbooks('', false);
 $gbook_id = empty($params['gbookid']) ? $this->GetPreference('defaultgbook') : $params['gbookid'];
 
 if ( count($gbooks) > 1 )
@@ -23,13 +23,9 @@ if ( count($gbooks) > 1 )
 	}
 	$smarty->assign('gbookselect', $this->CreateInputDropdown($id, 'gbookselect', $gbooklist, -1, $gbook_id, 'id="' . $id . 'gbookselect"'));
 	$smarty->assign('gbookselectjs', '
-	<script type="text/javascript">
-		$(function() {
-			$(\'#' . $id . 'gbookselect\').change( function() {
-				location.href = "' . str_replace('&amp;','&',$this->CreateLink($id, 'defaultadmin', $returnid, '', array('active_tab' => 'items'), '', true))  . '&' . $id . 'gbookid="+$(this).val();
-			});
+		$(\'#' . $id . 'gbookselect\').change( function() {
+			location.href = "' . str_replace('&amp;','&',$this->CreateLink($id, 'defaultadmin', $returnid, '', array('active_tab' => 'items'), '', true))  . '&' . $id . 'gbookid="+$(this).val();
 		});
-	</script>
 ');
 }
 else
@@ -39,6 +35,17 @@ else
 	$entries = $gbooks[0]['entries'];
 }
 
+// create filter dropdownfield
+$params['filter'] = empty($params['filter']) ? 'showall' : $params['filter'];
+$filterlist = array(lang('showall') => 'showall', lang('active') => 'active', lang('inactive') => 'inactive', $this->Lang('spam') => 'spam');
+$smarty->assign('prompt_filter', lang('filters'));
+$smarty->assign('filter', $this->CreateInputDropdown($id, 'filter', $filterlist, -1, $params['filter'], 'id="' . $id . 'filter"') );
+$smarty->assign('filterselectjs', '
+		$(\'#' . $id . 'filter\').change( function() {
+			location.href = "' . str_replace('&amp;','&',$this->CreateLink($id, 'defaultadmin', $returnid, '', array('gbookid' => $gbook_id, 'active_tab' => 'items'), '', true))  . '&' . $id . 'filter="+$(this).val();
+		});
+');
+
 // pagination
 $params['gbpage'] = empty($params['gbpage']) ? 1 : $params['gbpage'];
 $entries_per_page = 40;
@@ -47,19 +54,19 @@ $start = (($params['gbpage'] - 1) * $entries_per_page) + 1;
 
 $pagelinks = array();
 for ($i = 1; $i <= $pages; $i++) {
-	$pagelinks[$i] = $this->CreateLink($id, 'defaultadmin', $returnid, '', array ('gbookid' => $gbook_id, 'gbpage' => $i, 'active_tab' => 'items'), '', true);
+	$pagelinks[$i] = $this->CreateLink($id, 'defaultadmin', $returnid, '', array ('gbookid' => $gbook_id, 'gbpage' => $i, 'filter' => $params['filter'], 'active_tab' => 'items'), '', true);
 }
-$smarty->assign_by_ref('pagelinks', $pagelinks);
+$smarty->assign('pagelinks', $pagelinks);
 $smarty->assign('currentpage', $params['gbpage']);
 
 
-$items = Gbook_utils::GetEntries($gbook_id, $start, $entries_per_page, false);
+$items = Gbook_utils::GetEntries($gbook_id, $start, $entries_per_page, $params['filter']);
 foreach ( $items as $key=>$item )
 {
 	$spamrate = Gbook_utils::b8_exec('Classify', $item->title . ' ' . $item->rawmessage);
 	$items[$key]->spamrate = Gbook_utils::format_rating($spamrate);
 }
-$smarty->assign_by_ref('items', $items);
+$smarty->assign('items', $items);
 
 
 $smarty->assign('id', $this->Lang('id'));
@@ -71,36 +78,36 @@ $smarty->assign('spamrate', $this->Lang('spamrate'));
 $smarty->assign('active', lang('active'));
 $smarty->assign('create_date', $this->Lang('created'));
 $smarty->assign('modified_date', $this->Lang('modified'));
-$smarty->assign('expire_date', $this->Lang('expired'));
 $smarty->assign('approved_date', $this->Lang('approved'));
 
 
 $smarty->assign('itemcount', count($items));
 
 $smarty->assign('activefalselink', $this->CreateLink($id, 'edititem', $returnid,
-				    $themeObject->DisplayImage('icons/system/true.gif', lang('active'),'','','systemicon'),
-				    array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'switchactive')));
+				    $admintheme->DisplayImage('icons/system/true.gif', lang('active'),'','','systemicon'),
+				    array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'switchactive', 'filter'=>$params['filter'])));
 $smarty->assign('activetruelink', $this->CreateLink($id, 'edititem', $returnid,
-				    $themeObject->DisplayImage('icons/system/false.gif', lang('inactive'),'','','systemicon'),
-				    array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'switchactive')));
-$smarty->assign('editicon', $themeObject->DisplayImage ('icons/system/edit.gif', lang ('edit'), '', '', 'systemicon'));
+				    $admintheme->DisplayImage('icons/system/false.gif', lang('inactive'),'','','systemicon'),
+				    array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'switchactive', 'filter'=>$params['filter'])));
+$smarty->assign('editicon', $admintheme->DisplayImage('icons/system/edit.gif', lang ('edit'), '', '', 'systemicon'));
 $smarty->assign('editurl', $this->CreateLink($id, 'edititem', $returnid,
 				    lang ('edit'),
-				    array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'edit'), '', true));
+				    array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'edit', 'filter'=>$params['filter']), '', true));
 $smarty->assign('deletelink', $this->CreateLink($id, 'edititem', $returnid,
-					  $themeObject->DisplayImage('icons/system/delete.gif', lang ('delete'), '', '', 'systemicon'),
-					  array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'delete'), $this->Lang ('areyousure')));
-/*
+					  $admintheme->DisplayImage('icons/system/delete.gif', lang ('delete'), '', '', 'systemicon'),
+					  array ('gbookid' => $gbook_id, 'entryid' => 'QQ', 'mode'=>'delete', 'filter'=>$params['filter']), $this->Lang ('areyousure')));
+
 $smarty->assign('multiselect', $this->CreateInputCheckbox($id, 'multiselect[QQ]', 1));
 
-$smarty->assign('formstart', $this->CreateFormStart ($id, 'multiaction',$returnid,'post','', false, '', array('gbookid' => $gbook_id)));
+$smarty->assign('formstart', $this->CreateFormStart ($id, 'multiaction', $returnid, 'post', '', false, '', array('gbookid' => $gbook_id, 'filter' => $params['filter'])));
 $smarty->assign('formend', $this->CreateFormEnd());
 
 $multiactionlist = array(lang('delete') => 'delete', lang('active') => 'active', lang('inactive') => 'inactive');
-$smarty->assign('prompt_multiaction', $this->Lang('withselected'));
+$smarty->assign('prompt_multiaction', lang('selecteditems'));
 $smarty->assign('multiaction', $this->CreateInputDropdown($id, 'multiaction', $multiactionlist, -1) . ' ' . $this->CreateInputSubmit($id, 'multiactionsubmit', lang('apply'), '', '', $this->Lang('areyousuremulti')) );
 
-$link = $this->CreateLink($id, 'edititem', 0, $themeObject->DisplayImage('icons/system/newobject.gif', $this->Lang('additem'),'','','systemicon'), array(), '', false, false, '') .' '. $this->CreateLink($id, 'edititem', $returnid, $this->Lang("additem"), array("mode"=>"add"), '', false, false, 'class="pageoptions"');
+/*
+$link = $this->CreateLink($id, 'edititem', 0, $admintheme->DisplayImage('icons/system/newobject.gif', $this->Lang('additem'),'','','systemicon'), array(), '', false, false, '') .' '. $this->CreateLink($id, 'edititem', $returnid, $this->Lang("additem"), array("mode"=>"add"), '', false, false, 'class="pageoptions"');
 $smarty->assign('addlink', $link);
 */
 
