@@ -28,7 +28,7 @@ foreach ($items as $item)
 	$onerow->sort = $item['sort'];
 	if ( $i > 0 )
 	{
-		$onerow->moveup = $this->CreateLink($id, 'editsmileys', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/arrow-u.gif', lang('up'),'','','systemicon'), array('smileyid' => $item['smiley_id'], 'mode' => 'moveup'));
+		$onerow->moveup = $this->CreateLink($id, 'editsmileys', $returnid, $admintheme->DisplayImage('icons/system/arrow-u.gif', lang('up'),'','','systemicon'), array('smileyid' => $item['smiley_id'], 'mode' => 'moveup'));
 	}
 	else
 	{
@@ -37,20 +37,20 @@ foreach ($items as $item)
 
 	if ( $i < count($items) - 1 && count($items) > 1 )
 	{
-		$onerow->movedown = $this->CreateLink($id, 'editsmileys', $returnid, $gCms->variables['admintheme']->DisplayImage('icons/system/arrow-d.gif', lang('down'),'','','systemicon'), array('smileyid' => $item['smiley_id'], 'mode' => 'movedown'));
+		$onerow->movedown = $this->CreateLink($id, 'editsmileys', $returnid, $admintheme->DisplayImage('icons/system/arrow-d.gif', lang('down'),'','','systemicon'), array('smileyid' => $item['smiley_id'], 'mode' => 'movedown'));
 	}
 	else
 	{
 		$onerow->movedown = '';
 	}
 	$onerow->delete = $this->CreateLink($id, 'editsmileys', $returnid,
-					  $themeObject->DisplayImage('icons/system/delete.gif', lang('delete'), '', '', 'systemicon'),
+					  $admintheme->DisplayImage('icons/system/delete.gif', lang('delete'), '', '', 'systemicon'),
 					  array ('smileyid' => $item['smiley_id'], 'mode' => 'delete'), $this->Lang('areyousure'));
 	array_push($itemarray, $onerow);
 	$i++;
 }
 
-$smarty->assign_by_ref('items', $itemarray);
+$smarty->assign('items', $itemarray);
 
 
 $smarty->assign('formstart', $this->CreateFormStart ($id, 'editsmileys', $returnid, 'post', 'multipart/form-data', false, '', array('mode' => 'savesmileys')));
