@@ -26,6 +26,8 @@ $lang['gbookupdated'] = 'Guestbook is updated';
 $lang['gbookdeleted'] = 'Guestbook is deleted';
 $lang['entries_page'] = 'Number of entries per page';
 $lang['prevent_post_twice'] = 'Prevent consecutive messages by the same user (based on IP address)';
+$lang['use_captcha'] = 'Use captcha to activate spam-suspected messages (Captcha module needs to be installed)';
+$lang['allow_rating'] = 'Allow Star rating';
 $lang['allow_smilies'] = 'Allow Smilies';
 $lang['allow_notifications'] = 'Enable Notifications option';
 $lang['notification_subject'] = 'Notification email subject';
@@ -80,7 +82,7 @@ $lang['help_admin_section'] = 'Choose the Admin Section (or top-level Admin Menu
 $lang['send_notifications_to'] = 'Send notification of new entries to editor';
 //$lang['not_send_spamnotifications'] = 'Do not send notifications for suspected spam entries';
 $lang['max_spamrate_active'] = 'Maximum spamrating to automatically set an entry active on submit';
-$lang['max_spamrate_active_help'] = 'between 0 and 1, default 0.6. Lower value means tighter setting.';
+$lang['max_spamrate_active_help'] = 'between 0 and 1, default 0.6. Lower value means tighter setting. Advised to set on 0.4 or below';
 $lang['max_spamrate_notify'] = 'Maximum spamrating for sending a notification to editor';
 $lang['max_spamrate_notify_help'] = 'between 0 and 1, default 0.9. Higher value will increase the chance of getting notifications of spam entries.';
 $lang['max_spamrate_save'] = 'Maximum spamrating for saving a new entry';
@@ -95,6 +97,7 @@ $lang['name'] = 'Name';
 $lang['email'] = 'Email';
 $lang['title'] = 'Title';
 $lang['message'] = 'Message';
+$lang['rating'] = 'Rating';
 $lang['notify'] = 'Notify me on new messages';
 $lang['fe_submit'] = 'Submit';
 $lang['validation_errors'] = 'Please provide a valid entry for the marked fields and submit again.';
@@ -105,9 +108,15 @@ $lang['not_allowed_to_post_twice'] = '<p>Sorry. Due to spam protection it is not
 
 //Default Gbook message settings
 $lang['submission_response_cnt'] = '<p>Thank you for your feedback. Your message has been added to our guestbook.</p>';
-$lang['submission_response_spam_cnt'] = '<p>Thank you for your feedback.</p>
+$lang['submission_response_spam_cnt2'] = '<p>Thank you for your feedback.</p>
+{if empty($gbook_captcha)}
 <p>Your message however has been suspected to contain spam, therefore it needs approval before it will be displayed.</p>
-<p>Please notify us by sending an email.</p>';
+<p>Please notify us by sending an email.</p>
+{else}
+<p>Your message however has been suspected to contain spam, therefore it needs one next step before it will be displayed.</p>
+<p>Please complete the following challenge:</p>
+{$gbook_captcha} {$gbook_captcha_input}
+{/if}';
 $lang['admin_notification_subject_cnt'] = 'New Guestbook Entry';
 $lang['admin_notification_message_cnt'] = 'You received a new message in your {sitename} Guestbook.
 
@@ -120,7 +129,7 @@ $lang['help_alias'] = 'Use another guestbook than the default one. Check the Gue
 $lang['help_entryid'] = 'Use this parameter along with <code>action=\'detail\'</code> if you want to display only one guestbook entry. To get the latest entry, use <code>entryid=-1</code>';
 $lang['help_template'] = 'Use another template than the default one. Note that templates must be of the proper type, in accordance with the action parameter.';
 $lang['help'] = '<h3>What Does This Do?</h3>
-<p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
+<p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and star ratings. Your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
 <h3>How Do I Use It</h3>
 <p>To show the guestbook entries, just insert the module with the<code> {Gbook} </code>tag into the content section of a page.<br />
 You can display a form with the<code> {Gbook action=\'form\'} </code>tag.</p>
@@ -130,8 +139,10 @@ You can display a form with the<code> {Gbook action=\'form\'} </code>tag.</p>
 <p>Users with the \'Gbook: Use\' permission can edit guestbook entries in the backend.</p>
 
 <h3>Spam Protection</h3>
-<p>Gbook proudly uses the "b8" statistical (Bayesian) spam filter version 0.6, written by Tobias Leupold. This built-in spam protection system will only function after you have learned it how to interpret the messages by marking the first few entries as either "Spam" or "Ham". If the system has learned enough good as well as enough bad words, it will give spam messages a rating somewhere near 1, and ham messages will be rated somewhere near 0. Messages with a rating of 0.50 could not be rated because of too few matching words.<br />Note that it won\'t be of use to manually mark entries as spam or ham, which are already rated as such.</p>
+<p>Gbook uses a honeypot field (since version 2.2) which will prevent spam engines from posting. Make sure to keep the {$gbook_honeypot_input} field in your form template, and it stays hidden via css, otherwise nobody will be able to post messages.</p>
+<p>Next, Gbook proudly uses the "b8" statistical (Bayesian) spam filter version 0.6, written by Tobias Leupold. This built-in spam protection system will only function after you have learned it how to interpret the messages by marking the first few entries as either "Spam" or "Ham". If the system has learned enough good as well as enough bad words, it will give spam messages a rating somewhere near 1, and ham messages will be rated somewhere near 0. Messages with a rating of 0.50 could not be rated because of too few matching words.<br />Note that it won\'t be of use to manually mark entries as spam or ham, which are already rated as such.</p>
 <p>If you want to know more of this excellent spam protection system, you can visit <a href="http://nasauber.de/opensource/b8/">nasauber.de</a>.</p>
+<p>When a new message is suspected to contain spam, though with such a low value that it was saved but not active, you can serve your visitor a chaptcha challenge. For this the Captcha module needs to be installed and the guestbook setting "Use captcha" needs to be checked.</p>
 
 <h3>Customisation</h3>
 <p>The Guestbooks-tab in the admin section allows you to create more separate guestbooks. Each can have its own settings.<br />
