@@ -586,13 +586,14 @@ class Gbook_utils
 		$config = cmsms()->GetConfig();
 		
 		$config_b8 = array(
-			'storage' => 'mysqli'
+			'storage' => 'mysqli_gbook'
 		);
 
 		$config_storage = array(
 			'database'   => $config['db_name'],
 			'table_name' => cms_db_prefix().'module_gbook_b8_wordlist',
-			'host'       => $config['db_hostname'] . (!empty($config['db_port']) ? ':' . $config['db_port'] : ''),
+			'host'       => $config['db_hostname'],
+			'port'       => $config['db_port'],
 			'user'       => $config['db_username'],
 			'pass'       => $config['db_password']
 		);
